@@ -2,8 +2,7 @@
 from django.core.files.base import ContentFile
 from django.db.models import F
 from rest_framework import mixins, status, viewsets
-from rest_framework.parsers import FileUploadParser, FormParser, \
-    MultiPartParser
+from rest_framework.parsers import FileUploadParser, FormParser, MultiPartParser
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.renderers import BrowsableAPIRenderer, JSONRenderer
 from rest_framework.response import Response
@@ -12,8 +11,8 @@ from rest_framework.serializers import ValidationError
 from db.api import filters, pagination, serializers
 from db.api.perms import SafeMethodsWithPermission
 from db.api.renderers import BrowserableJSONLDRenderer, JSONLDRenderer
-from db.base.models import Artifact, DemodData, LatestTleSet, Mode, \
-    Satellite, Transmitter
+from db.base.helpers import gridsquare
+from db.base.models import Artifact, DemodData, LatestTleSet, Mode, Satellite, Transmitter
 from db.base.tasks import update_satellite
 
 
@@ -131,6 +130,14 @@ class TelemetryView(  # pylint: disable=R0901
         # Create file out of frame string
         frame = ContentFile(request.data.get('frame'), name='sids')
         data['payload_frame'] = frame
+        # Create observer
+        try:
+            qth = gridsquare(data['lat'], data['lng'])
+        except Exception:  # pylint: disable=W0703
+            data['observer'] = 'Unknown'
+        else:
+            observer = '{0}-{1}'.format(data['station'], qth)
+            data['observer'] = observer
 
         serializer = serializers.SidsSerializer(data=data)
         serializer.is_valid(raise_exception=True)
